from setuptools import setup, find_packages

setup(
    name='veripress',
    version='1.0.4',
    packages=find_packages(),
    url='https://github.com/veripress/veripress',
    license='MIT License',
    author='Richard Chien',
    author_email='richardchienthebest@gmail.com',
    description='A blog engine for hackers.',
    install_requires=[
        'Flask', 'Flask-Caching', 'PyYAML', 'mistune', 'Pygments'
    ],
    include_package_data=True,
    platforms='any',
    entry_points=dict(
        console_scripts=['veripress=veripress_cli:main']
    )
)



import click

cli = click.Group(help='This is a blog engine for hackers. '
                       'You can use this to serve a blog, a wiki or anything else you like.')


def main():
    cli.main()


import veripress_cli.init
import veripress_cli.serve
import veripress_cli.theme
import veripress_cli.generate
import veripress_cli.deploy
